@@ -8,25 +8,26 @@ use Pod::Usage qw(pod2usage);
 
 my %opt = (
 	port => 12345,
-	perl => $^X, # allow the user to supply the path to another perl
+	perl => $^X,        # allow the user to supply the path to another perl
 	host => '127.0.0.1',
 );
 
 usage() if not @ARGV;
-GetOptions(\%opt,
+GetOptions(
+	\%opt,
 	'help',
 	'port=i',
 	'perl=s',
 ) or usage();
 usage() if $opt{help};
 
-my ($script, @args) = @ARGV;
+my ( $script, @args ) = @ARGV;
 
 
 my $pid = fork();
 die if not defined $pid;
-  
-if (not $pid) {
+
+if ( not $pid ) {
 	local $ENV{PERLDB_OPTS} = "RemotePort=$opt{host}:$opt{port}";
 	exec("$opt{perl} -d $script @args");
 }
@@ -44,24 +45,24 @@ say 'listening';
 
 # my @cmd = ($opt{perl}, '-d', @ARGV);
 # {
-	# local $ENV{PERLDB_OPTS} = "RemotePort=$opt{host}:$opt{port}";
-	# IPC::Run::run(\@cmd, sub {}, \&out, \&err);
+# local $ENV{PERLDB_OPTS} = "RemotePort=$opt{host}:$opt{port}";
+# IPC::Run::run(\@cmd, sub {}, \&out, \&err);
 # }
 # say 'launched';
 
 # sub out {
-	# print "OUT @_";
+# print "OUT @_";
 # }
 # sub err {
-	# print "ERR @_";
+# print "ERR @_";
 # }
 
 # my $process;
 # if ($^O =~ /win32/i) {
-	# require Win32::Process;
-	# require Win32;
-	# local $ENV{PERLDB_OPTS} = "RemotePort=$opt{host}:$opt{port}";
-	# Win32::Process::Create($process, $opt{perl}, "-d $script @args", 0, 0, cwd);
+# require Win32::Process;
+# require Win32;
+# local $ENV{PERLDB_OPTS} = "RemotePort=$opt{host}:$opt{port}";
+# Win32::Process::Create($process, $opt{perl}, "-d $script @args", 0, 0, cwd);
 # }
 # print "launched " . $process->GetProcessID .  "\n";
 
@@ -70,14 +71,14 @@ my $out = $debugger->get;
 print $out;
 my $last_step;
 while (1) {
-	chomp(my $input = <STDIN>);
-	if ($input eq '') {
+	chomp( my $input = <STDIN> );
+	if ( $input eq '' ) {
 		next if not $last_step;
 		$input = $last_step;
 	}
 
 	given ($input) {
-		when (['h', '?']) {
+		when ( [ 'h', '?' ] ) {
 			help();
 		}
 		when ('s') {
@@ -114,7 +115,7 @@ while (1) {
 			#print $out;
 			print "Invalid command\n";
 		}
-	}	
+	}
 }
 
 sub help {
@@ -130,15 +131,16 @@ h or ? - help
 END_HELP
 
 }
-			
 
-  # ...
+
+# ...
 
 # On Windows kill() does not seem to have effect
 # print "Killing the script...\n";
 END {
 	kill 9, $pid if $pid;
 }
+
 # Win32::Process
 #$process->Kill(0);
 
