@@ -7,11 +7,10 @@ use warnings;
 # Turn on $OUTPUT_AUTOFLUSH
 $| = 1;
 
-foreach (0..3)
-{
- my $line = $_;
- last unless defined $line;
- print "$_ : $line \n";
+foreach ( 0 .. 3 ) {
+	my $line = $_;
+	last unless defined $line;
+	print "$_ : $line \n";
 }
 
 1;
